@@ -13,6 +13,8 @@ function check_secret_state {
     return $?
 }
 
+OPENSSL_VERSION=$(openssl version | cut -d' ' -f2)
+
 #check wether a set of cert secrets already exist and intact
 function check_cert_state {
     local _name=$1
@@ -635,7 +637,13 @@ function gen_haproxy_cert {
   TRUSTED_SSL_TRUSTSTORE_JKS=$(cat $_tmpdir/trusted-ssl-certs-cms_truststore.jks|base64 -w 0)
 
   #update related java keystore: trusted-ssl-cert:client_auth_keystore.jks
-  openssl pkcs12 -export -out ${_tmpdir}/clients.pfx -in ${_tmpdir}/clients.pem -passout pass:$_storepass
+
+  if [[ "$OPENSSL_VERSION" =~ ^3\. ]]; then
+        openssl pkcs12 -export -out ${_tmpdir}/clients.pfx -in ${_tmpdir}/clients.pem -passout pass:$_storepass -legacy
+  else
+        openssl pkcs12 -export -out ${_tmpdir}/clients.pfx -in ${_tmpdir}/clients.pem -passout pass:$_storepass
+  fi
+
   keytool -importkeystore \
 	-srckeystore ${_tmpdir}/clients.pfx -srcstoretype PKCS12 \
 	-destkeystore ${_tmpdir}/trusted-ssl-certs-client_auth_keystore.jks -deststoretype JKS \
@@ -702,7 +710,11 @@ function gen_haproxy_cert {
 	#re-gen peer client_auth_keystore.jks&fingerprint using user provided peer/app.pem instead
 	rm -f ${_tmpdir}/peer-cms-trusted-ssl-cert-client_auth_keystore.jks
 	rm -f ${_tmpdir}/peer-cms-trusted-ssl-cert-cms_fingerprint
-  	openssl pkcs12 -export -out ${_tmpdir}/peer_clients_pfx -in ${_tmpdir}/peer_clients_pem -passout pass:$_storepass
+    if [[ "$OPENSSL_VERSION" =~ ^3\. ]]; then
+          openssl pkcs12 -export -out ${_tmpdir}/peer_clients_pfx -in ${_tmpdir}/peer_clients_pem -passout pass:$_storepass -legacy
+    else
+          openssl pkcs12 -export -out ${_tmpdir}/peer_clients_pfx -in ${_tmpdir}/peer_clients_pem -passout pass:$_storepass
+    fi
   	keytool -importkeystore \
 	  -srckeystore ${_tmpdir}/peer_clients_pfx -srcstoretype PKCS12 \
 	  -destkeystore ${_tmpdir}/peer-cms-trusted-ssl-cert-client_auth_keystore.jks -deststoretype JKS \
