@@ -7,6 +7,8 @@ get_product_parameter()
     yq ".$PRODUCT_KEY" $PRODUCTSVAR_FILE
 }
 
+OPENSSL_VERSION=$(openssl version | cut -d' ' -f2)
+
 function ctrl_c() {
         echo "** Trapped CTRL-C ** Stopped by User"
 }
@@ -486,8 +488,11 @@ function gen_java_cert() {
       kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.crt}' | base64 -d - > $ca_folder/tls.crt
       kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.ca\.crt}' | base64 -d - > $ca_folder/ca.crt
       kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.key}' | base64 -d - > $ca_folder/tls.key
-
+    if [[ "$OPENSSL_VERSION" =~ ^3\. ]]; then
+      openssl pkcs12 -export -in $ca_folder/tls.crt -inkey $ca_folder/tls.key -out $ca_folder/tls.p12 -passout pass:$pass -legacy
+    else
       openssl pkcs12 -export -in $ca_folder/tls.crt -inkey $ca_folder/tls.key -out $ca_folder/tls.p12 -passout pass:$pass
+    fi
       keytool -importkeystore -v -srckeystore $ca_folder/tls.p12 -srcstoretype pkcs12 -destkeystore $ca_folder/tls.keystore -deststoretype jks -storepass $pass -srcstorepass $pass -noprompt 2>/dev/null
       keytool -import -trustcacerts -alias ca -file $ca_folder/ca.crt -keystore $ca_folder/ca.truststore -storetype jks -storepass $pass -noprompt
 
